@@ -7,6 +7,11 @@
  ******************************************************************************/
 #include "cplib.cc"
 
+#if !defined(__DJGPP__)
+#include "../jobs/csext.h"
+#endif
+
+
 #if defined(__DJGPP__) || defined(_WIN32)
  #define DIR_DEPARATOR '\\'
 #else
@@ -388,6 +393,82 @@ unsigned TablePosStart;
 }
 
 
+#if !defined(__DJGPP__)
+FILE *Flock = NULL;
+string FileLock;
+#endif
+
+
+
+/** This procedure compares "Src" file with "Dest"
+ * @param[in]	 Dest	destination file name.
+ * @param[in]	 Src	source file name.
+ * @return	0 on success; <0 on failure. */
+int CompareFile(FILE *F1, FILE *F2)
+{
+char Buff1[32];
+char Buff2[32];
+size_t sz1, sz2;
+
+ if(F1==NULL || F2==NULL) return -1;
+
+ do
+ {
+   sz1 = fread(Buff1,1,sizeof(Buff1),F1);
+   sz2 = fread(Buff2,1,sizeof(Buff2),F2);
+   if(sz1 != sz2) return -2;
+   if(!memcmp(Buff1,Buff2,sz1)) return -3;
+ } while(sz1 > 0);
+
+return(0);
+}
+
+
+/// Multithreading build fails when a file growing in progress is accessed by
+/// another job. It is safe to create a different file and reneme it when it is finished.
+int FcloseEpilog(FILE *Ftmp, const char *TmpFilename, const char *PersistentFilename)
+{
+string FileName2;
+FILE *Fper;
+
+ ForgeFname(FileName2, PersistentFilename);
+
+ if((Fper=fopen(FileName2(),"rb"))!=NULL)	// Destroy older persistent file if exists.
+ {
+   if(Ftmp)
+   {
+     fseek(Ftmp,0,SEEK_SET);
+     if(CompareFile(Ftmp,Fper) == 0)
+     {
+       printf("Both files \"%s\" to \"%s\" have same contents!\n", TmpFilename, FileName2());
+       fclose(Ftmp);
+       fclose(Fper);
+       remove(TmpFilename);  // No need to replace file
+       return 0;
+     }     
+   }
+   fclose(Fper);	// Second file is different must be replaced.   
+   remove(FileName2());		// Unlink older persistent name.
+ }
+
+ if(Ftmp) {fclose(Ftmp);Ftmp=NULL;}
+ if(rename(TmpFilename, FileName2()))
+ {
+   printf("Cannot rename file from \"%s\" to \"%s\"!\n", TmpFilename, FileName2());
+#if !defined(__DJGPP__)
+   if(Flock)
+   {
+     fclose(Flock);
+     unlink(FileLock());
+     Flock=NULL;
+   }
+#endif
+   return -1;
+ }
+return 0;
+}
+
+
 int main(int argc, char *argv[])
 {
 FILE *F;
@@ -419,6 +500,25 @@ string FileName;
      }
    }
 
+
+#if !defined(__DJGPP__)
+ //Sleep(1000);
+ ForgeFname(FileLock,"lock.lck");
+ while((Flock=fopen(FileLock(),"rb")) != NULL)
+ {
+   fclose(Flock);
+   if(remove(FileLock())==0) break;
+   printf("Lock \"%s\" found, waiting for cleanup from concurrent app.\n", FileLock());
+   Sleep(500);
+ }
+ while((Flock=fopen(FileLock(),"wbx")) == NULL)
+ {
+   printf("Lock \"%s\" found, waiting for cleanup from concurrent app.\n", FileLock());
+   Sleep(500);
+ }
+ fprintf(Flock,"running");
+#endif
+
  //printf("\n dir=%s.",Directory);
 
  //printf("%ld\n",coreleft());
@@ -473,7 +573,7 @@ string FileName;
  printf("%ld\n",coreleft());
 
 
- ForgeFname(FileName, "trn.trn");
+ ForgeFname(FileName, "trn.new");
  if((F=fopen(FileName(),"w"))==NULL)
  {
    printf("Cannot write to the file \"%s\"", FileName());
@@ -494,14 +594,10 @@ string FileName;
  CreateTranslator(trn,cpwp6, internal);
  WriteTranslator(cpwp6,internal,trn,F);
 
-
-
-
 //if(heapcheck()<=0)
 //	asm int 3;
 //goto end;
 
-
 /*
 CreateTranslator(trn,cpkam,internal);
 WriteTranslator(cpkam,internal,trn,F);
@@ -510,21 +606,20 @@ CreateTranslator(trn,cp1250,internal);
 WriteTranslator(cp1250,internal,trn,F);
 */
 
-
 /*
 trn=CreateTranslator(cp1250,cpkam);
 WriteTranslator(cp1250,cpkam,trn,F);
 */
 
 //end:
- fclose(F);
+ if(FcloseEpilog(F,FileName(),"trn.trn")) return -1;
 
 
  LoadTextCodePage("html",llHTML);
  llHTML.sort(strcmp);
  CreateCodePage("html",cphtml,llHTML);
 
- ForgeFname(FileName, "html.trn");
+ ForgeFname(FileName, "html.new");
  if((F=fopen(FileName(),"w"))==NULL)
  {
    printf("Cannot write to the file \"%s\"", FileName());
@@ -534,12 +629,10 @@ WriteTranslator(cp1250,cpkam,trn,F);
  CreateTranslator(trn,cphtml, internal);
  WriteTranslator(cphtml,internal,trn,F);
  WriteStringTable(F,cphtml,llHTML);
- fclose(F);
+ if(FcloseEpilog(F,FileName(),"html.trn")) return -1;
 
 
- FileName=Directory; 
- if(FileName.length()>0) FileName+=DIR_DEPARATOR;
- FileName += "cpg.trn";
+ ForgeFname(FileName, "cpg.new");
  if((F=fopen(FileName(),"w"))==NULL)
  {
    printf("Cannot write to the file \"%s\"", FileName());
@@ -611,11 +704,10 @@ WriteTranslator(cp1250,cpkam,trn,F);
  CreateTranslator(trn, internal, iso_8859_2);
  WriteTranslator(internal, iso_8859_2, trn, F);
 */
-
- fclose(F);
+ if(FcloseEpilog(F,FileName(),"cpg.trn")) return -1;
 
 
- ForgeFname(FileName, "mtef.trn");
+ ForgeFname(FileName, "mtef.new");
  if((F=fopen(FileName(),"w"))==NULL)
  {
    printf("Cannot write to the file \"%s\"", FileName());
@@ -628,11 +720,11 @@ WriteTranslator(cp1250,cpkam,trn,F);
 
  CreateTranslator(trn,mtef2,internal);
  WriteTranslator(mtef2,internal,trn,F);
- fclose(F);
+ if(FcloseEpilog(F,FileName(),"mtef.trn")) return -1;
 
 
 SkipMtef:
- ForgeFname(FileName, "macroman.trn");
+ ForgeFname(FileName, "macroman.new");
  if((F=fopen(FileName(),"w"))==NULL)
  {
    printf("Cannot write to the file \"%s\"", FileName());
@@ -641,10 +733,18 @@ SkipMtef:
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
  CreateTranslator(trn,MAC_ROMAN,internal);
  WriteTranslator(MAC_ROMAN,internal,trn,F);
- fclose(F);
+ if(FcloseEpilog(F,FileName(),"macroman.trn")) return -1;
 
 
  trn.erase();
 
+#if !defined(__DJGPP__)
+ if(Flock)
+ {
+   fclose(Flock);
+   unlink(FileLock());
+ }
+#endif
+
 return 0;
 }
\ No newline at end of file
