@@ -37,14 +37,22 @@ return num1;
 }
 
 
-
 /// Emit Postscript command for font selection.
 /// @param[in,out]	Text	String builter that holds whole PS image.
 /// @param[in]		FontSize  Size of font in [points]
 /// @param[in]		FontName  Optional naome of font.
 void Font2PS(string & Text, const float FontSize, const char *FontName)
 {
-  Text.cat_printf("/%s findfont %2.2f scalefont setfont", FontName, FontSize);
+  Text.cat_printf("/%s findfont", FontName);
+  if(FontSize > 0.005)
+    {
+    if(FontSize>50 || (FontSize>1 && fabs(FontSize-(int)FontSize)<0.00999f))  // Do not request decimals for font larger than 50pt
+	Text.cat_printf(" %d", (int)FontSize);
+    else
+        Text.cat_printf(" %.2f", FontSize);
+    Text += " scalefont";
+    }
+  Text += " setfont";
 }
 
 
@@ -418,6 +426,7 @@ unsigned VectorRectangle::isInside(float xp, float yp) const
 temp_string VectorRectangle::Export2EPS(PS_State *PSS) const
 {
 string str;
+float x, y;
 
   if(PSS != NULL)
   {
@@ -426,15 +435,19 @@ string str;
     PS_Attr(str,PSS);
   }
 
-  bool ContextSaved = false;
-  if(Tx) 
-    ContextSaved = Tx->ApplyTransform(str);
-  
-  str.cat_printf("\nnewpath\n%2.2f %2.2f moveto", LeftRect, BottomRect);
-  str.cat_printf("\n%2.2f %2.2f lineto", LeftRect, TopRect);
-  str.cat_printf("\n%2.2f %2.2f lineto", RightRect, TopRect);
-  str.cat_printf("\n%2.2f %2.2f lineto", RightRect, BottomRect);
-  str.cat_printf("\n%2.2f %2.2f lineto", LeftRect, BottomRect);
+  x=LeftRect; y=BottomRect;
+  if(Tx) Tx->ApplyTransform(x,y);
+  str.cat_printf("\nnewpath\n%2.2f %2.2f moveto", x, y);
+  x=LeftRect; y=TopRect;
+  if(Tx) Tx->ApplyTransform(x,y);
+  str.cat_printf("\n%2.2f %2.2f lineto", x, y);
+  x=RightRect; y=TopRect;
+  if(Tx) Tx->ApplyTransform(x,y);
+  str.cat_printf("\n%2.2f %2.2f lineto", x, y);
+  x=RightRect; y=BottomRect;
+  if(Tx) Tx->ApplyTransform(x,y);
+  str.cat_printf("\n%2.2f %2.2f lineto", x, y);
+  str.cat_printf("\nclosepath");
 
   if(BrushStyle!=0)
   {
@@ -445,8 +458,6 @@ string str;
     str += "\nstroke";
   }  
 
-  if(ContextSaved) str += "\ngrestore";
-
 return temp_string(str);
 }
 
@@ -496,7 +507,7 @@ temp_string VectorRectangleArc::Export2EPS(PS_State *PSS) const
 float Ty = 1;
 bool ContextSaved = false;
 
-  if(fabs(Hradius)<1e-5 || fabs(Vradius)<1e-5)
+  if(fabs(Hradius)<1e-5 || fabs(Vradius)<1e-5 || Tx!=NULL)
       return VectorRectangle::Export2EPS(PSS);
 
   string PSData;
@@ -508,8 +519,8 @@ bool ContextSaved = false;
     PS_Attr(PSData, PSS);
   }
 
-  if(Tx) 
-    ContextSaved = Tx->ApplyTransform(PSData);
+  //if(Tx) 
+  //  ContextSaved = Tx->ApplyTransform(PSData);
   
   float Y_ll = BottomRect;
   float Y_ur = TopRect;
@@ -1159,37 +1170,83 @@ TextContainer::~TextContainer()
 }
 
 
+/// This function discards all accents from a postscript text line.
+/// Such line could be used for metrics calculation.
+temp_string ExtractAccents(const string &LineStr)
+{
+  temp_string LineNoAccent = replacesubstring(LineStr,") show (","");
+  LineNoAccent = replacesubstring(LineNoAccent,") accentshow (","");
+  LineNoAccent = replacesubstring(LineNoAccent,") ACCENTSHOW (","");
+  LineNoAccent = replacesubstring(LineNoAccent,"\\302)(","");		// acute
+  LineNoAccent = replacesubstring(LineNoAccent,"\\317)(","");		// charon
+  LineNoAccent = replacesubstring(LineNoAccent,"\\312)(","");		// ring
+  LineNoAccent = replacesubstring(LineNoAccent,"\\301)(","");		// grave
+  LineNoAccent = replacesubstring(LineNoAccent,"\\310)(","");		// umlaut
+  LineNoAccent = replacesubstring(LineNoAccent,"\\47)(","");		 //insert space before apostrophe \\47
+return LineNoAccent;
+}
+
+
 /// Append show only when needed. The intent is not to emit "() show". Too much empty
 /// strings only bloat image. Of course that "(\()" is a string containing one character.
 /// @param[in,out]	str	String that needs either cleanup or adding \show.
-void AppendShow(string &str, unsigned char HorizontalPos)
+/// @param[in,out]	strLine Newly added chunk of text. Will be erased on return.
+/// @param[in]		HorizontalPos	Horizontal position placement.
+void AppendShow(string &str, string &strLine, const unsigned char HorizontalPos)
 {
-  int len = length(str);
+  int len = length(strLine);
   if(len==0) return;
   if(len>=2)
     {
-    if(str[len-2]=='(' && str[len-1]==')')
+    if(strLine[len-2]=='(' && strLine[len-1]==')')
       {
-      if(len>=3 && str[len-3]!='\\')		// Is the curly brace preffixed?
+      if(len>=3 && strLine[len-3]!='\\')		// Is the curly brace preffixed?
         {
-        if(len>=3 && str[len-3]==' ') len--;	//Remove orphaned space.
-        str = copy(str,0,len-2);
+        if(len>=3 && strLine[len-3]==' ') len--;	//Remove orphaned space.
+        strLine = copy(strLine,0,len-2);
+        str += strLine;
+	erase(strLine);
         return;
         }
       }
     }
-  if((HorizontalPos & 6) == 6)
+
+  switch((HorizontalPos & 6))   
     {
-    str += "\ndup stringwidth pop -2 div"
-	   "\n0 rmoveto";
+    case 2: if(strstr(strLine,") show (")!=NULL)		// TA_RIGHT
+	    {
+	      str += ExtractAccents(strLine);
+	      str += "\nstringwidth pop -1 mul 0 rmoveto";
+	      str += strLine;
+            }
+	    else
+            {
+	      str += strLine;
+	      str += "\ndup stringwidth pop -1 mul 0 rmoveto";
+	    }
+	    break;
+    case 6: if(strstr(strLine,") show (")!=NULL)		// TA_CENTER
+	    {
+	      str += ExtractAccents(strLine);
+	      str += "\nstringwidth pop -2 div 0 rmoveto";
+	      str += strLine;
+	    }
+	    else
+            {
+	      str += strLine;
+	      str += "\ndup stringwidth pop -2 div 0 rmoveto";
+            }
+	    break;
+    default: str += strLine;
     }
   str += "\nshow";
+  erase(strLine);
 }
 
 
 temp_string TextContainer::Export2EPS(PS_State *PSS) const
 {
-string str;
+string str, strLine;
 RGB_Record BkTextColor;
 float CurPosX = PosX;
 float CurPosY = PosY;
@@ -1221,7 +1278,7 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         FixPsAccent(Text[i]->contents,"\\\"{","(\\310)");	// umlaut
         FixPsAccent2(Text[i]->contents,"\\accent39","( \\47)"); //insert space before apostrophe \\47
         
-        if(i>0) AppendShow(str,TextAllign);
+        if(i>0) AppendShow(str,strLine,TextAllign);
 	
         if(PSS!=NULL)
         {
@@ -1237,16 +1294,8 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
         {          
 	  if(i>0 || PSS==NULL || PSS->FontSize!=Text[i]->size || PSS->FontName!=Text[i]->TargetFont)
           {          
-	    str += "\n/";
-	    str += Text[i]->TargetFont;
-	    str += " findfont ";
-	    const float FontSz = Text[i]->size*2.66f;
-            if(FontSz>50 || (FontSz>1 && fabs(FontSz-(int)FontSz)<0.00999f))  // Do not request decimals for font larger than 50pt
-	      str.cat_printf("%d", (int)FontSz);
-	    else
-              str.cat_printf("%.2f", FontSz);
-	    str += " scalefont setfont";
-
+	    str += "\n";
+	    Font2PS(str, Text[i]->size*2.66f, Text[i]->TargetFont);
             if(!TextRotated && PSS!=NULL)
 	    {
               PSS->FontSize = Text[i]->size;
@@ -1267,26 +1316,27 @@ const bool TextRotated = fabs(NormAngleDEG(FontOrientation)) > 0.01;
 	  *ScanS2 = 0;
           //if(ScanS!=NULL && *ScanS!=0)
 	  {
-            str += "\n(";	
-            str += ScanS;
-	    str += ')';
+            strLine += "\n(";	
+            strLine += ScanS;
+	    strLine += ')';
           }
 	  *ScanS2 = '\n';
 	  ScanS = ScanS2 + 1;
 
 	  CurPosY -= 1.01 * Text[i]->size*2.66f;
-	  str.cat_printf("\nshow newpath %2.2f %2.2f moveto", CurPosX, CurPosY);
+	  AppendShow(str,strLine,TextAllign);
+	  str.cat_printf(" newpath %2.2f %2.2f moveto", CurPosX, CurPosY);
 	}
 
 	//if(ScanS!=NULL && *ScanS!=0)
 	{
-          str += "\n(";	
-          str += ScanS;
-	  str += ')';
+          strLine += "\n(";	
+          strLine += ScanS;
+	  strLine += ')';
         }
       }      
     }
-    AppendShow(str,TextAllign);
+    AppendShow(str,strLine,TextAllign);
     if(TextRotated)
     {    
       str += "\ngrestore";
