@@ -19,6 +19,7 @@
 
 #define mm2PSu(x)   ( (float)(x)*71/25.4 )
 
+
 void Font2PS(string & Text, const float FontSize, const char *FontName="Times-Roman");
 void Color2PS(string & Text, const RGB_Record & TextColor);
 
@@ -38,7 +39,7 @@ typedef struct
 	char FillPattern;
 	BYTE LineStyle;
         BYTE PolyFillMode;		///< 0-standard; 1-alternating
-	BYTE TextAllign;
+	BYTE TextAllign;		///< 0-TA_LEFT; 2-TA_RIGHT; 6-TA_CENTER
 
 	float LineWidth;
 	RGB_Record FillColor;
@@ -310,7 +311,7 @@ public:
   virtual unsigned isInside(float xp, float yp) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
 
-  vecTransform *Tx;
+  AbstractTransformXY *Tx;
   float	BottomRect, TopRect, RightRect, LeftRect;
 };
 
