@@ -544,8 +544,8 @@ while (ActualPos < end_of_code)
 	  by == '|' ||
 	  (by >= ' ' && by <= 'z'))
 	     {
-	     if (by == 10 || by == 13) by = ' ';
-	     if (by == '$') StrBeg += '\\';	 // $ is transformed to \$
+	     if(by == 10 || by == 13) by = ' ';
+	     if(by=='$' || by=='%') StrBeg += '\\';	 // $ is transformed to \$
 
 	     StrBeg += char(by);
 	     if(log==NULL)
@@ -561,7 +561,7 @@ while (ActualPos < end_of_code)
 	      continue;
 	      }
 
-      if (by == 0xC0)       /*extended character*/
+      if(by == 0xC0)       /*extended character*/
 	    {			/*why special wp characters are in equations?*/
 	    Rd_word(wpd, &wchr_code);
 
@@ -754,7 +754,7 @@ char BoxType;
 DiskImage:
 	      Box.Contents = 3; // content image - every images are internally converted into WPG
 	      end_of_code -= 4;
-	      Box.CaptionPos=ActualPos+117L;
+	      Box.CaptionPos = ActualPos+117L;
 	      i=(end_of_code<Box.CaptionPos)?0:(WORD)(end_of_code-Box.CaptionPos);
 	      fseek(wpd, ActualPos+115L, SEEK_SET); // receive a caption size
 	      Rd_word(wpd,&Box.CaptionSize);
