@@ -644,8 +644,7 @@ static int ecPopRtfState(TconvertedPass1_RTF *cq)
     psaveOld = cq->psave;
 
     AttrFit(cq->attr,psaveOld->CharA,s);
-    if(s!="") fputs(s(),cq->strip);
-
+    if(!s.isEmpty()) fputs(s(),cq->strip);
 
     cq->fSkipDestIfUnk=psaveOld->fSkipDestIfUnk &&
 		       (cq->fSkipDestIfUnk || (!cq->fSkipDestIfUnk && (cq->rds!=rdsNorm)));
@@ -835,9 +834,9 @@ static void ChangeCpTranslator(TconvertedPass1_RTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#ChangeCpTranslator() ");fflush(cq->log);
 #endif
- if(cq->Parameter=="")
+ if(cq->Parameter.isEmpty())
 	{cq->ConvertCpg = NULL;return;}
- cq->ConvertCpg = GetTranslator("cp"+cq->Parameter+"TOinternal");
+ cq->ConvertCpg = GetTranslator(string("cp"+cq->Parameter+"TOinternal"));
  if(cq->ConvertCpg==NULL || cq->ConvertCpg==&Dummy)
    {
    if(cq->err != NULL)
@@ -913,7 +912,7 @@ RGBQuad RGB;
 		    goto FINISH;
 	   default: goto FINISH;
 	   }
-	cq->ActualPos=ftell(cq->wpd);;
+	cq->ActualPos=ftell(cq->wpd);
 	}
    return;
 FINISH:
@@ -948,19 +947,19 @@ do {
 	case 3:if(Str[0]=='\"') Str=copy(Str,1,length(Str)-1);
 	       if(Str[length(Str)-1]=='\"') Str=copy(Str,0,length(Str)-1);
 	       Str.ToLower();
-	       CpTrn = GetTranslator(Str+"TOinternal");
+	       CpTrn = GetTranslator(string(Str+"TOinternal"));
 	       if(CpTrn==NULL) {state=0;break;}  //This should be reviewed!!!!!!
 	       CharacterStr(cq,Ext_chr_str(pos,cq,CpTrn));
 	       state=0;
 	       break;
 
-	case 10:if(Str!="")
+	case 10:if(!Str.isEmpty())
 		  {
 		  fprintf(cq->strip, " \\pageref{%s}",Str());
 		  state=0;
 		  }
 		break;
-	case 20:if(Str!="")
+	case 20:if(!Str.isEmpty())
 		  {
 		  fprintf(cq->strip, " \\ref{%s}",Str());
 		  state=0;
@@ -985,7 +984,7 @@ do {
 	   continue;
 	   }
 	}
-   } while(Str!="");
+   } while(!Str.isEmpty());
 }
 
 
@@ -1389,7 +1388,7 @@ static void MakeLabelRTF(TconvertedPass1_RTF *cq)
 	     cq->rds=rdsSkip;
 	     }
 	else c=fgetc(cq->wpd); 		//read the closing curly brace
-  if(LBL_Text!="")
+  if(!LBL_Text.isEmpty())
     {
     fprintf(cq->strip, "%s\\label{%s}",cq->char_on_line>0?" ":"",LBL_Text());
     if(cq->char_on_line == false)
@@ -1966,7 +1965,7 @@ RTFnext:
 		putc(cq->by, cq->log);
 	     break;
       default:
-	     if(cq->Keyword != "")
+	     if(!cq->Keyword.isEmpty())
 		{
 		char *Str;
 		fprintf(cq->log, "\n%*s[\\%s",
