@@ -1764,7 +1764,7 @@ int p;
 		continue;
 		}
 #ifdef _REENTRANT
-	if(!strcmp(name, "jobs")||!strcmp(name, "Jobs")) /*-no-columns*/
+	if(!strcmp(name, "jobs")||!strcmp(name, "Jobs")) /*-no-jobs*/
 		{
 		Job4Run = 0;
 		continue;
